XmlParseError

Enum XmlParseError 

pub enum XmlParseError {
    NoRootComponent,
    MultipleRootComponents,
    ParseError(XmlError),
    MalformedHierarchy(String, String),
    RenderDom(RenderDomError),
    Component(ComponentParseError),
}

Variants



NoRootComponent

No <app></app> root component present



MultipleRootComponents

The DOM can only have one root component, not multiple.



ParseError(XmlError)

Note: Sadly, the error type can only be a string because xmlparser returns all errors as strings. There is an open PR to fix this deficiency, but since the XML parsing is only needed for hot-reloading and compiling, it doesn’t matter that much.



MalformedHierarchy(String, String)

Invalid hierarchy close tags, i.e <app></p></app>



RenderDom(RenderDomError)

A component raised an error while rendering the DOM - holds the component name + error string



Component(ComponentParseError)

Something went wrong while parsing an XML component